@@ -41,6 +41,9 @@ DEALINGS IN THE SOFTWARE.
 #include <KLocalizedString>
 #include <KSharedConfig>
 #include <KConfigGroup>
+#if !OXYGEN_USE_KDE4
+#include <Kdelibs4Migration>
+#endif
 
 #define SCROLLBAR_DEFAULT_WIDTH 15
 #define SCROLLBAR_MINIMUM_WIDTH 10
@@ -79,6 +82,7 @@ namespace Oxygen
         connect( _splitterProxyEnabled, SIGNAL(toggled(bool)), SLOT(updateChanged()) );
         connect( _mnemonicsMode, SIGNAL(currentIndexChanged(int)), SLOT(updateChanged()) );
         connect( _animationsEnabled, SIGNAL(toggled(bool)), SLOT(updateChanged()) );
+        connect( _viewDrawFocusIndicator, SIGNAL(toggled(bool)), SLOT(updateChanged()) );
         connect( _viewTriangularExpanderSize, SIGNAL(currentIndexChanged(int)), SLOT(updateChanged()) );
         connect( _viewDrawTreeBranchLines, SIGNAL(toggled(bool)), SLOT(updateChanged()) );
         connect( _scrollBarWidth, SIGNAL(valueChanged(int)), SLOT(updateChanged()) );
@@ -98,13 +102,13 @@ namespace Oxygen
         StyleConfigData::setToolBarDrawItemSeparator( _toolBarDrawItemSeparator->isChecked() );
         StyleConfigData::setSplitterProxyEnabled( _splitterProxyEnabled->isChecked() );
         StyleConfigData::setMnemonicsMode( _mnemonicsMode->currentIndex() );
+        StyleConfigData::setViewDrawFocusIndicator( _viewDrawFocusIndicator->isChecked() );
         StyleConfigData::setViewTriangularExpanderSize( triangularExpanderSize() );
         StyleConfigData::setViewDrawTreeBranchLines( _viewDrawTreeBranchLines->isChecked() );
         StyleConfigData::setScrollBarWidth( _scrollBarWidth->value() );
         StyleConfigData::setScrollBarAddLineButtons( _scrollBarAddLineButtons->currentIndex() );
         StyleConfigData::setScrollBarSubLineButtons( _scrollBarSubLineButtons->currentIndex() );
         StyleConfigData::setMenuHighlightMode( menuMode() );
-        StyleConfigData::setViewTriangularExpanderSize( triangularExpanderSize() );
         StyleConfigData::setWindowDragMode( _windowDragMode->currentIndex()  );
 
         if( _expertMode )
@@ -122,6 +126,15 @@ namespace Oxygen
         StyleConfigData::self()->writeConfig();
         #else
         StyleConfigData::self()->save();
+
+        //update the KDE4 config to match
+        Kdelibs4Migration migration;
+        const QString kde4ConfigDirPath = migration.saveLocation("config");
+
+        QScopedPointer<KConfig> kde4Config(new KConfig);
+        StyleConfigData::self()->config()->copyTo(kde4ConfigDirPath+"/oxygenrc", kde4Config.data());
+        kde4Config->sync();
+
         #endif
 
         // emit dbus signal
@@ -267,6 +280,7 @@ namespace Oxygen
         else if( _splitterProxyEnabled->isChecked() != StyleConfigData::splitterProxyEnabled() ) modified = true;
         else if( menuMode() != StyleConfigData::menuHighlightMode() ) modified = true;
         else if( _animationsEnabled->isChecked() != StyleConfigData::animationsEnabled() ) modified = true;
+        else if( _viewDrawFocusIndicator->isChecked() != StyleConfigData::viewDrawFocusIndicator() ) modified = true;
         else if( triangularExpanderSize() != StyleConfigData::viewTriangularExpanderSize() ) modified = true;
         else if( _animationConfigWidget && _animationConfigWidget->isChanged() ) modified = true;
         else if( _windowDragMode->currentIndex() != StyleConfigData::windowDragMode() ) modified = true;
@@ -300,6 +314,7 @@ namespace Oxygen
         _animationsEnabled->setChecked( StyleConfigData::animationsEnabled() );
         _windowDragMode->setCurrentIndex( StyleConfigData::windowDragMode() );
 
+        _viewDrawFocusIndicator->setChecked( StyleConfigData::viewDrawFocusIndicator() );
         switch( StyleConfigData::viewTriangularExpanderSize() )
         {
             case StyleConfigData::TE_TINY: _viewTriangularExpanderSize->setCurrentIndex(0); break;
