@@ -83,7 +83,11 @@ namespace Oxygen
 
             rect = rect.translated( widget->mapTo( widget->window(), widget->rect().topLeft() ) );
             widget = widget->window();
+            #if QT_VERSION < 0x050000
+            out = QPixmap::grabWidget( widget, rect );
+            #else
             out = widget->grab( rect );
+            #endif
 
         } else {
 
@@ -190,7 +194,7 @@ namespace Oxygen
 
         QWidgetList widgets;
         if( widget->autoFillBackground() )
-        { widgets.push_back( widget ); }
+        { widgets.append( widget ); }
 
         QWidget *parent(0);
 
@@ -201,7 +205,7 @@ namespace Oxygen
             if( !( parent->isVisible() && parent->rect().isValid() ) ) continue;
 
             // store in list
-            widgets.push_back( parent );
+            widgets.append( parent );
 
             // stop at topLevel
             if( parent->isTopLevel() || parent->autoFillBackground() ) break;
@@ -244,7 +248,7 @@ namespace Oxygen
             QWidget* w = widgets.at(i);
             w->render( &p, -widget->mapTo( w, rect.topLeft() ), rect, 0 );
         }
-        
+
         // end
         p.end();
 
